%define major		0
%define libname_qt5	%mklibname %{name}-qt5_ %{major}
%define develname_qt5	%mklibname %{name}-qt5 -d

%define libname_qt6	%mklibname %{name}-qt6_ %{major}
%define develname_qt6	%mklibname %{name}-qt6 -d

%bcond_without	qt5
%bcond_without	qt6

Name:		kcolorpicker
Version:	0.3.0
Release:	%mkrel 2
Summary:	Qt based Color Picker with pop-up menu
License:	LGPL-3.0-or-later
Group:		Graphical desktop/KDE
URL:		https://github.com/ksnip/kColorPicker
Source:		https://github.com/ksnip/kColorPicker/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	ninja-build
# Qt5
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Test)
BuildRequires:	cmake(Qt5Widgets)
%endif
# Qt6
%if %{with qt6}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)
%endif

%description
QToolButton with color popup menu with lets you select a color. The
popup features a color dialog button which can be used to add custom
colors to the popup menu.

#------------------------------------------------
%if %{with qt5}

%package -n	%{libname_qt5}
Summary:	Qt5 based Color Picker with pop-up menu
Group:		System/Libraries

%description -n %{libname_qt5}
QToolButton with color pop-up menu with lets you select a color. The
pop-up features a color dialog button which can be used to add custom
colors to the popup menu.

#------------------------------------------------

%package -n	%{develname_qt5}
Summary:	Development package for %{name} Qt5
Group:		Development/C++
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{name}-qt5-devel = %{version}-%{release}

%description -n	%{develname_qt5}
Header files for development with %{name} Qt5.

%endif
#------------------------------------------------
%if %{with qt6}

%package -n	%{libname_qt6}
Summary:	Qt6 based Color Picker with pop-up menu
Group:		System/Libraries

%description -n %{libname_qt6}
QToolButton with color pop-up menu with lets you select a color. The
pop-up features a color dialog button which can be used to add custom
colors to the popup menu.

#------------------------------------------------

%package -n	%{develname_qt6}
Summary:	Development package for %{name} Qt6
Group:		Development/C++
Requires:	%{libname_qt6} = %{version}-%{release}
Provides:	%{name}-qt6-devel = %{version}-%{release}

%description -n	%{develname_qt6}
Header files for development with %{name} Qt6.

%endif
#------------------------------------------------

%prep
%autosetup -p1 -n kColorPicker-%{version}

%build
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_qt5 \
	-G Ninja \
	-DBUILD_EXAMPLE=ON
%cmake_build
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_qt6 \
	-G Ninja \
	-DBUILD_EXAMPLE=ON \
	-DBUILD_WITH_QT6:BOOL=ON
%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_install
%endif

%if %{with qt5}
%files -n %{libname_qt5}
%license LICENSE
%doc README.md
%{_libdir}/libkColorPicker-Qt5.so.%{major}{,.*}

%files -n %{develname_qt5}
%doc README.md
%{_includedir}/kColorPicker-Qt5/
%{_libdir}/libkColorPicker-Qt5.so
%{_libdir}/cmake/kColorPicker-Qt5/
%endif

%if %{with qt6}
%files -n %{libname_qt6}
%license LICENSE
%doc README.md
%{_libdir}/libkColorPicker-Qt6.so.%{major}{,.*}

%files -n %{develname_qt6}
%doc README.md
%{_includedir}/kColorPicker-Qt6/
%{_libdir}/libkColorPicker-Qt6.so
%{_libdir}/cmake/kColorPicker-Qt6/
%endif


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 0.3.0-2.mga10
+ Revision: 2223154
- Mageia 10 Mass Rebuild

* Thu Jan 25 2024 daviddavid <daviddavid> 0.3.0-1.mga10
+ Revision: 2034161
- new version: 0.3.0
- add Qt6 support

* Thu Sep 01 2022 papoteur <papoteur> 0.2.0-1.mga9
+ Revision: 1883313
- new 0.2.0

* Sun Apr 03 2022 umeabot <umeabot> 0.1.6-2.mga9
+ Revision: 1842458
- Mageia 9 Mass Rebuild

* Tue May 25 2021 daviddavid <daviddavid> 0.1.6-1.mga9
+ Revision: 1728131
- new version: 0.1.6

* Thu Feb 25 2021 daviddavid <daviddavid> 0.1.5-1.mga9
+ Revision: 1690680
- new version: 0.1.5
- now libmajor is 0

* Thu Dec 17 2020 umeabot <umeabot> 0.1.4-2.mga8
+ Revision: 1658649
- Rebuild for new Qt5

* Fri Jun 19 2020 daviddavid <daviddavid> 0.1.4-1.mga8
+ Revision: 1597036
- new version: 0.1.4

* Fri Apr 03 2020 daviddavid <daviddavid> 0.1.1-1.mga8
+ Revision: 1564099
- initial package kcolorpicker (needed for ksnip)

